@@ -18,8 +18,7 @@ use std::{collections::HashMap, convert::From, sync::Arc, time::Duration};
 use tokio::{
     io::{stdin, stdout, AsyncBufReadExt, AsyncWriteExt, BufReader},
     runtime::Runtime,
-    task,
-    signal,
+    signal, task,
 };
 
 macro_rules! tryc {
@@ -50,12 +49,8 @@ async fn handle_writes_loop(
             for req in batch.drain(..) {
                 if let Some(val) = by_id.get(&req.id) {
                     use std::io::Write;
-                    let typ = match Typ::get(&req.value) {
-                        None => "none",
-                        Some(t) => t.name(),
-                    };
                     if let Some(path) = publisher.path(val.id()) {
-                        write!(buf, "{}|{}|{}\n", path, typ, &req.value)?;
+                        write!(buf, "{}|{}\n", path, &req.value)?;
                     }
                 }
             }
@@ -133,14 +128,14 @@ pub(crate) fn run(config: Config, bcfg: BindCfg, timeout: Option<u64>, auth: Aut
                     "missing path",
                     m.next().ok_or_else(|| anyhow!("missing path"))
                 );
-                let typ_or_null = tryc!(
-                    "missing type",
-                    m.next().ok_or_else(|| anyhow!("missing type"))
-                );
-                let val = if typ_or_null == "null" {
-                    Value::Null
-                } else {
-                    let typ = tryc!("invalid type", typ_or_null.parse::<Typ>());
+                let typ = {
+                    let v = tryc!(
+                        "missing type",
+                        m.next().ok_or_else(|| anyhow!("malformed line"))
+                    );
+                    tryc!("parse type", v.parse::<Typ>())
+                };
+                let val = {
                     let v = tryc!(
                         "missing value",
                         m.next().ok_or_else(|| anyhow!("malformed data"))
